//
// C++ Interface: CSoundEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CSOUNDEDITDLG_H
#define CSOUNDEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_sounddlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CSoundEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CSoundEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CSoundEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
 
private slots:
 
protected:
    Ui::SoundEditDlg ui;    
    FolderListItem *point;
    
private:
    QWidget *myParent;
};
#endif
